SystemOrganization addCategory: #ConfigurationOfWebClient!

Object subclass: #ConfigurationOfWebClient
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfWebClient'!

!ConfigurationOfWebClient commentStamp: 'ar 5/5/2010 21:25' prior: 0!
Metacello configuration for WebClient.

	ConfigurationOfWebClient load.
!

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:33'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:33'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:33'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:33'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:34'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:34'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'ar 5/5/2010 21:11'!
project

	^self new project! !

!ConfigurationOfWebClient class methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:34'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfWebClient methodsFor: 'baselines' stamp: 'DaleHenrichs 7/3/2010 11:31'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #common do:[
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/WebClient'.

		"Just the fact it exists"
		spec package: 'WebClient-Core'.

		"Tests require existence of Core"
		spec package: 'WebClient-Tests' with:[spec requires: 'WebClient-Core'].

		"Documentation doesn't require Core/Tests, but HelpSystem"
		spec package: 'WebClient-Help' with:[spec requires: 'HelpSystem'].

		"HTTP requires core. Except on Pharo where it also requires Pharo
		(i.e., order HTTP after Core+Pharo). Expressed below via #includes:"
		spec package: 'WebClient-HTTP' with:[spec requires: 'WebClient-Core'].
		
		"Q: HelpSystem - will this always been loaded? It should only be loaded
		if WebClient-Help is loaded. A: Unnecessary to be explicit since Help is
		in the implicit default group already and unless loading the implicit
		default group HelpSystem will only be loaded if required."
		spec project: 'HelpSystem' with:[
			"Copied verbatim from MetacelloReferenceConfig.
			Don't understand all of it and not covered in tutorials."
			spec 
				className: 'ConfigurationOfHelpSystem';
				repository: 'http://www.squeaksource.com/MetacelloRepository'.
		].
	
		"Just copy and pasted, not sure this is the right way."
		spec project: 'Seaside' with:[
			spec 
				className: 'ConfigurationOfSeaside30';
				repository: 'http://www.squeaksource.com/MetacelloRepository'.
		].
	
		"WebClient-Seaside requires WebClient-Core and Seaside"
		spec package: 'WebClient-Seaside' with: [ 
		 	spec requires: #('WebClient-Core' 'Seaside' ) ].
	].
	spec for: #pharo do:[
		"Include WebClient-Pharo with WebClient-Core when on Pharo"
		spec 
			package: 'WebClient-Core' with:[spec includes: 'WebClient-Pharo'];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core'].
	].
! !

!ConfigurationOfWebClient methodsFor: 'baselines' stamp: 'JohnMcKeon 4/4/2012 23:31'!
baseline11: spec 
	<version: '1.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/WebClient'.	
		spec project: 'HelpSystem' with:[
			spec 
				className: 'ConfigurationOfHelpSystem';
				repository: 'http://www.squeaksource.com/MetacelloRepository'.
		].
		spec project: 'Seaside' with:[
			spec 
				className: 'ConfigurationOfSeaside30';
				repository: 'http://www.squeaksource.com/MetacelloRepository'.
		].
	
		
		spec 
			package: 'WebClient-Core';
			package: 'WebClient-HTTP' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Help' with: [ spec requires: 'HelpSystem' ];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Seaside' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Tests' with: [ spec requires: 'WebClient-Core' ].
		spec
			group: 'default' with: #('Core' 'Tests' 'Help');
			group: 'Core' with: #('WebClient-Core');
			group: 'Help' with: #('WebClient-Help');
			group: 'HTTP' with: #('WebClient-HTTP');
			group: 'Server' with: #('WebClient-Seaside');
			group: 'Tests' with: #('WebClient-Tests');
			group: 'Dev' with: #('default' 'HTTP' 'Server').. ].
		
			spec for: #pharo do:[
		spec 
			package: 'WebClient-Core' with:[spec includes: 'WebClient-Pharo'];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core'].
	].! !

!ConfigurationOfWebClient methodsFor: 'baselines' stamp: 'JohnMcKeon 4/4/2012 23:52'!
baseline13: spec 
	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/WebClient'.	
		spec project: 'HelpSystem' with:[
			spec 
				className: 'ConfigurationOfHelpSystem';
				repository: 'http://www.squeaksource.com/MetacelloRepository'.
		].
		spec project: 'Seaside30' with:[
			spec 
				className: 'ConfigurationOfSeaside30';
				repository: 'http://www.squeaksource.com/MetacelloRepository'.
		].
	
		
		spec 
			package: 'WebClient-Core';
			package: 'WebClient-HTTP' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Help' with: [ spec requires: 'HelpSystem' ];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Seaside' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Tests' with: [ spec requires: 'WebClient-Core' ].
		spec
			group: 'default' with: #('Core' 'Tests' 'Help');
			group: 'Core' with: #('WebClient-Core');
			group: 'Help' with: #('WebClient-Help');
			group: 'HTTP' with: #('WebClient-HTTP');
			group: 'Seaside' with: #('Seaside30' 'default' 'WebClient-Seaside');
			group: 'Tests' with: #('WebClient-Tests');
			group: 'Dev' with: #('default' 'HTTP' 'Seaside').. ].
		
			spec for: #pharo do:[
		spec 
			package: 'WebClient-Core' with:[spec includes: 'WebClient-Pharo'];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core'].
	].! !

!ConfigurationOfWebClient methodsFor: 'baselines' stamp: 'topa 2/26/2013 10:30'!
baseline14: spec 
	<version: '1.4-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/WebClient'.	
		spec project: 'HelpSystem' with:[
			spec 
				className: 'ConfigurationOfHelpSystem';
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].	
		spec 
			package: 'WebClient-Core';
			package: 'WebClient-HTTP' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Help' with: [ spec requires: 'HelpSystem' ];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Tests' with: [ spec requires: 'WebClient-Core' ].
		spec
			group: 'default' with: #('Core' 'Tests' 'Help');
			group: 'Core' with: #('WebClient-Core');
			group: 'Help' with: #('WebClient-Help');
			group: 'HTTP' with: #('WebClient-HTTP');
			group: 'Tests' with: #('WebClient-Tests');
			group: 'Dev' with: #('default' 'HTTP'). ].
		
			spec for: #pharo do:[
		spec 
			package: 'WebClient-Core' with:[spec includes: 'WebClient-Pharo'];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core'] ].! !

!ConfigurationOfWebClient methodsFor: 'baselines' stamp: 'topa 4/4/2013 19:21'!
baseline15: spec 
	<version: '1.5-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Account for Repository change. HelpSystem is both in Squeak and Pharo.'.
		spec repository: 'http://ss3.gemstone.com/ss/WebClient'.

		spec 
			package: 'WebClient-Core';
			package: 'WebClient-HTTP' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Help';
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core' ];
			package: 'WebClient-Tests' with: [ spec requires: 'WebClient-Core' ].
		spec
			group: 'default' with: #('Core' 'Tests' 'Help');
			group: 'Core' with: #('WebClient-Core');
			group: 'Help' with: #('WebClient-Help');
			group: 'HTTP' with: #('WebClient-HTTP');
			group: 'Tests' with: #('WebClient-Tests');
			group: 'Dev' with: #('default' 'HTTP'). ].
		
	spec for: #pharo do:[
		spec 
			package: 'WebClient-Core' with:[spec includes: 'WebClient-Pharo'];
			package: 'WebClient-Pharo' with: [ spec requires: 'WebClient-Core'] ].! !

!ConfigurationOfWebClient methodsFor: 'accessing' stamp: 'PaulDeBruicker 8/2/2010 20:33'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfWebClient methodsFor: 'as yet unclassified' stamp: 'topa 4/4/2013 19:25'!
stable: spec
	<symbolicVersion: #stable>

	spec for: #'squeak4.1' version: '1.3'.
	spec for: #'squeak4.2' version: '1.3'.
	spec for: #common version: '1.5'.! !

!ConfigurationOfWebClient methodsFor: 'version' stamp: 'DaleHenrichs 7/3/2010 11:32'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do:[
		spec blessing: #release.
		spec
			project: 'HelpSystem' with: '1.1';
			project: 'Seaside' with: '3.0.0-alpha5.15'.
		spec 
			package: 'WebClient-Core' with: 'WebClient-Core-ar.16';
			package: 'WebClient-Tests' with: 'WebClient-Tests-ar.7';
			package: 'WebClient-Help' with: 'WebClient-Help-ar.5';
			package: 'WebClient-HTTP' with: 'WebClient-HTTP-ar.1'.
	].
	spec for: #pharo do:[
		spec blessing: #alpha.
		spec package: 'WebClient-Pharo' with: 'WebClient-Pharo-ar.1'.
	].
! !

!ConfigurationOfWebClient methodsFor: 'versions' stamp: 'PaulDeBruicker 8/2/2010 19:47'!
version11: spec 
	<version: '1.1' imports: #('1.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec
			project: 'HelpSystem' with: '1.1';
			project: 'Seaside' with: '3.0.0-rc1'.
		spec 
			package: 'WebClient-Core' with: 'WebClient-Core-ar.54';
			package: 'WebClient-Tests' with: 'WebClient-Tests-ar.21';
			package: 'WebClient-HTTP' with: 'WebClient-HTTP-ar.1';
			package: 'WebClient-Seaside' with: 'WebClient-Seaside-ar.5';
			package: 'WebClient-Help' with: 'WebClient-Tests-ar.9'.
			].
		spec for: #pharo do: [
		spec blessing: #release.
		spec 
			package: 'WebClient-Pharo' with: 'WebClient-Pharo-ar.3'.]
		
		
		! !

!ConfigurationOfWebClient methodsFor: 'versions' stamp: 'MarcoSchmidt 10/12/2010 12:29'!
version12: spec
	<version: '1.2' imports: #('1.1')>

	spec for: #common do: [
		spec author: 'MarcoSchmidt'.
		spec timestamp: '10/12/2010 12:29'.
		spec blessing: #development.
		spec 
			project: 'HelpSystem' with: '1.1';
			project: 'Seaside' with: '3.0.0-rc1'.
		spec 
			package: 'WebClient-Core' with: 'WebClient-Core-ar.81';
			package: 'WebClient-Tests' with: 'WebClient-Tests-ar.36';
			package: 'WebClient-HTTP' with: 'WebClient-HTTP-ar.1';
			package: 'WebClient-Seaside' with: 'WebClient-Seaside-ar.5';
			package: 'WebClient-Help' with: 'WebClient-Tests-ar.9'.].
	spec for: #pharo do: [
		spec blessing: #release.
		spec package: 'WebClient-Pharo' with: 'WebClient-Pharo-ar.4'.].! !

!ConfigurationOfWebClient methodsFor: 'versions' stamp: 'JohnMcKeon 4/5/2012 00:04'!
version13: spec
	<version: '1.3' imports: #('1.3-baseline')>

	spec for: #common do: [
		spec author: 'MarcoSchmidt'.
		spec timestamp: '04/04/2012 12:29'.
		spec blessing: #development.
		spec 
			project: 'HelpSystem' with: '1.1';
			project: 'Seaside30' with: '3.0.7'.
		spec 
			package: 'WebClient-Core' with: 'WebClient-Core-ar.90';
			package: 'WebClient-Tests' with: 'WebClient-Tests-ar.45';
			package: 'WebClient-HTTP' with: 'WebClient-HTTP-ar.1';
			package: 'WebClient-Seaside' with: 'WebClient-Seaside-ar.10';
			package: 'WebClient-Help' with: 'WebClient-Help-ar.10'.].
	spec for: #pharo do: [
		spec blessing: #release.
		spec package: 'WebClient-Pharo' with: 'WebClient-Pharo-ar.5'.].! !

!ConfigurationOfWebClient methodsFor: 'versions' stamp: 'topa 2/26/2013 10:31'!
version14: spec
	<version: '1.4' imports: #('1.4-baseline')>

	spec for: #common do: [
		spec author: 'pmm'.  "fixed by topa on 26 February 2013 10:31:33 am"
		spec timestamp: '08/27/2012 11:06'.
		spec blessing: #development.
		spec 
			project: 'HelpSystem' with: '1.1'.
		spec 
			package: 'WebClient-Core' with: 'WebClient-Core-ar.90';
			package: 'WebClient-Tests' with: 'WebClient-Tests-ar.45';
			package: 'WebClient-HTTP' with: 'WebClient-HTTP-ar.1';
			package: 'WebClient-Help' with: 'WebClient-Help-ar.10' ].
	spec for: #pharo do: [
		spec blessing: #release.
		spec package: 'WebClient-Pharo' with: 'WebClient-Pharo-ar.5' ]! !

!ConfigurationOfWebClient methodsFor: 'versions' stamp: 'topa 4/5/2013 07:33'!
version15: spec
	<version: '1.5' imports: #('1.5-baseline')>

	spec for: #common do: [
		spec author: 'topa'. 
		spec timestamp: '4/4/2013 19:22'. "MetacelloPlatform current timestamp"
		spec blessing: #release.
		spec 
			package: 'WebClient-Core' with: 'WebClient-Core-topa.93';
			package: 'WebClient-Tests' with: 'WebClient-Tests-fbs.47';
			package: 'WebClient-HTTP' with: 'WebClient-HTTP-ar.1';
			package: 'WebClient-Help' with: 'WebClient-Help-ar.10' ].
	spec for: #pharo do: [
		spec package: 'WebClient-Pharo' with: 'WebClient-Pharo-ar.5' ]! !
